// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/model.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fmodel_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fmodel_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018001 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/axis_aligned_box.pb.h"
#include "ignition/msgs/joint.pb.h"
#include "ignition/msgs/link.pb.h"
#include "ignition/msgs/pose.pb.h"
#include "ignition/msgs/visual.pb.h"
#include "ignition/msgs/vector3d.pb.h"
#include "ignition/msgs/header.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fmodel_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fmodel_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fmodel_2eproto;
namespace ignition {
namespace msgs {
class Model;
struct ModelDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern ModelDefaultTypeInternal _Model_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::Model* Arena::CreateMaybeMessage<::ignition::msgs::Model>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

// ===================================================================

class IGNITION_MSGS_VISIBLE Model final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.Model) */ {
 public:
  inline Model() : Model(nullptr) {}
  ~Model() override;
  explicit constexpr Model(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  Model(const Model& from);
  Model(Model&& from) noexcept
    : Model() {
    *this = ::std::move(from);
  }

  inline Model& operator=(const Model& from) {
    CopyFrom(from);
    return *this;
  }
  inline Model& operator=(Model&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Model& default_instance() {
    return *internal_default_instance();
  }
  static inline const Model* internal_default_instance() {
    return reinterpret_cast<const Model*>(
               &_Model_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(Model& a, Model& b) {
    a.Swap(&b);
  }
  inline void Swap(Model* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Model* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline Model* New() const final {
    return new Model();
  }

  Model* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<Model>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const Model& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const Model& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Model* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.Model";
  }
  protected:
  explicit Model(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kJointFieldNumber = 6,
    kLinkFieldNumber = 7,
    kVisualFieldNumber = 9,
    kModelFieldNumber = 12,
    kNameFieldNumber = 2,
    kHeaderFieldNumber = 1,
    kPoseFieldNumber = 5,
    kScaleFieldNumber = 10,
    kBoundingBoxFieldNumber = 13,
    kIdFieldNumber = 3,
    kIsStaticFieldNumber = 4,
    kDeletedFieldNumber = 8,
    kSelfCollideFieldNumber = 11,
  };
  // repeated .ignition.msgs.Joint joint = 6;
  int joint_size() const;
  private:
  int _internal_joint_size() const;
  public:
  void clear_joint();
  ::ignition::msgs::Joint* mutable_joint(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Joint >*
      mutable_joint();
  private:
  const ::ignition::msgs::Joint& _internal_joint(int index) const;
  ::ignition::msgs::Joint* _internal_add_joint();
  public:
  const ::ignition::msgs::Joint& joint(int index) const;
  ::ignition::msgs::Joint* add_joint();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Joint >&
      joint() const;

  // repeated .ignition.msgs.Link link = 7;
  int link_size() const;
  private:
  int _internal_link_size() const;
  public:
  void clear_link();
  ::ignition::msgs::Link* mutable_link(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Link >*
      mutable_link();
  private:
  const ::ignition::msgs::Link& _internal_link(int index) const;
  ::ignition::msgs::Link* _internal_add_link();
  public:
  const ::ignition::msgs::Link& link(int index) const;
  ::ignition::msgs::Link* add_link();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Link >&
      link() const;

  // repeated .ignition.msgs.Visual visual = 9;
  int visual_size() const;
  private:
  int _internal_visual_size() const;
  public:
  void clear_visual();
  ::ignition::msgs::Visual* mutable_visual(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Visual >*
      mutable_visual();
  private:
  const ::ignition::msgs::Visual& _internal_visual(int index) const;
  ::ignition::msgs::Visual* _internal_add_visual();
  public:
  const ::ignition::msgs::Visual& visual(int index) const;
  ::ignition::msgs::Visual* add_visual();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Visual >&
      visual() const;

  // repeated .ignition.msgs.Model model = 12;
  int model_size() const;
  private:
  int _internal_model_size() const;
  public:
  void clear_model();
  ::ignition::msgs::Model* mutable_model(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Model >*
      mutable_model();
  private:
  const ::ignition::msgs::Model& _internal_model(int index) const;
  ::ignition::msgs::Model* _internal_add_model();
  public:
  const ::ignition::msgs::Model& model(int index) const;
  ::ignition::msgs::Model* add_model();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Model >&
      model() const;

  // string name = 2;
  void clear_name();
  const std::string& name() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_name(ArgT0&& arg0, ArgT... args);
  std::string* mutable_name();
  PROTOBUF_MUST_USE_RESULT std::string* release_name();
  void set_allocated_name(std::string* name);
  private:
  const std::string& _internal_name() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_name(const std::string& value);
  std::string* _internal_mutable_name();
  public:

  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // .ignition.msgs.Pose pose = 5;
  bool has_pose() const;
  private:
  bool _internal_has_pose() const;
  public:
  void clear_pose();
  const ::ignition::msgs::Pose& pose() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Pose* release_pose();
  ::ignition::msgs::Pose* mutable_pose();
  void set_allocated_pose(::ignition::msgs::Pose* pose);
  private:
  const ::ignition::msgs::Pose& _internal_pose() const;
  ::ignition::msgs::Pose* _internal_mutable_pose();
  public:
  void unsafe_arena_set_allocated_pose(
      ::ignition::msgs::Pose* pose);
  ::ignition::msgs::Pose* unsafe_arena_release_pose();

  // .ignition.msgs.Vector3d scale = 10;
  bool has_scale() const;
  private:
  bool _internal_has_scale() const;
  public:
  void clear_scale();
  const ::ignition::msgs::Vector3d& scale() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Vector3d* release_scale();
  ::ignition::msgs::Vector3d* mutable_scale();
  void set_allocated_scale(::ignition::msgs::Vector3d* scale);
  private:
  const ::ignition::msgs::Vector3d& _internal_scale() const;
  ::ignition::msgs::Vector3d* _internal_mutable_scale();
  public:
  void unsafe_arena_set_allocated_scale(
      ::ignition::msgs::Vector3d* scale);
  ::ignition::msgs::Vector3d* unsafe_arena_release_scale();

  // .ignition.msgs.AxisAlignedBox bounding_box = 13;
  bool has_bounding_box() const;
  private:
  bool _internal_has_bounding_box() const;
  public:
  void clear_bounding_box();
  const ::ignition::msgs::AxisAlignedBox& bounding_box() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::AxisAlignedBox* release_bounding_box();
  ::ignition::msgs::AxisAlignedBox* mutable_bounding_box();
  void set_allocated_bounding_box(::ignition::msgs::AxisAlignedBox* bounding_box);
  private:
  const ::ignition::msgs::AxisAlignedBox& _internal_bounding_box() const;
  ::ignition::msgs::AxisAlignedBox* _internal_mutable_bounding_box();
  public:
  void unsafe_arena_set_allocated_bounding_box(
      ::ignition::msgs::AxisAlignedBox* bounding_box);
  ::ignition::msgs::AxisAlignedBox* unsafe_arena_release_bounding_box();

  // uint32 id = 3;
  void clear_id();
  ::PROTOBUF_NAMESPACE_ID::uint32 id() const;
  void set_id(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_id() const;
  void _internal_set_id(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // bool is_static = 4;
  void clear_is_static();
  bool is_static() const;
  void set_is_static(bool value);
  private:
  bool _internal_is_static() const;
  void _internal_set_is_static(bool value);
  public:

  // bool deleted = 8;
  void clear_deleted();
  bool deleted() const;
  void set_deleted(bool value);
  private:
  bool _internal_deleted() const;
  void _internal_set_deleted(bool value);
  public:

  // bool self_collide = 11;
  void clear_self_collide();
  bool self_collide() const;
  void set_self_collide(bool value);
  private:
  bool _internal_self_collide() const;
  void _internal_set_self_collide(bool value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.Model)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Joint > joint_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Link > link_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Visual > visual_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Model > model_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr name_;
  ::ignition::msgs::Header* header_;
  ::ignition::msgs::Pose* pose_;
  ::ignition::msgs::Vector3d* scale_;
  ::ignition::msgs::AxisAlignedBox* bounding_box_;
  ::PROTOBUF_NAMESPACE_ID::uint32 id_;
  bool is_static_;
  bool deleted_;
  bool self_collide_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fmodel_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// Model

// .ignition.msgs.Header header = 1;
inline bool Model::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool Model::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& Model::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& Model::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Model.header)
  return _internal_header();
}
inline void Model::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Model.header)
}
inline ::ignition::msgs::Header* Model::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* Model::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Model.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* Model::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* Model::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Model.header)
  return _msg;
}
inline void Model::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Model.header)
}

// string name = 2;
inline void Model::clear_name() {
  name_.ClearToEmpty();
}
inline const std::string& Model::name() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Model.name)
  return _internal_name();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Model::set_name(ArgT0&& arg0, ArgT... args) {
 
 name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Model.name)
}
inline std::string* Model::mutable_name() {
  std::string* _s = _internal_mutable_name();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Model.name)
  return _s;
}
inline const std::string& Model::_internal_name() const {
  return name_.Get();
}
inline void Model::_internal_set_name(const std::string& value) {
  
  name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Model::_internal_mutable_name() {
  
  return name_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Model::release_name() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Model.name)
  return name_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Model::set_allocated_name(std::string* name) {
  if (name != nullptr) {
    
  } else {
    
  }
  name_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), name,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Model.name)
}

// uint32 id = 3;
inline void Model::clear_id() {
  id_ = 0u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 Model::_internal_id() const {
  return id_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 Model::id() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Model.id)
  return _internal_id();
}
inline void Model::_internal_set_id(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  
  id_ = value;
}
inline void Model::set_id(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_id(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Model.id)
}

// bool is_static = 4;
inline void Model::clear_is_static() {
  is_static_ = false;
}
inline bool Model::_internal_is_static() const {
  return is_static_;
}
inline bool Model::is_static() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Model.is_static)
  return _internal_is_static();
}
inline void Model::_internal_set_is_static(bool value) {
  
  is_static_ = value;
}
inline void Model::set_is_static(bool value) {
  _internal_set_is_static(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Model.is_static)
}

// .ignition.msgs.Pose pose = 5;
inline bool Model::_internal_has_pose() const {
  return this != internal_default_instance() && pose_ != nullptr;
}
inline bool Model::has_pose() const {
  return _internal_has_pose();
}
inline const ::ignition::msgs::Pose& Model::_internal_pose() const {
  const ::ignition::msgs::Pose* p = pose_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Pose&>(
      ::ignition::msgs::_Pose_default_instance_);
}
inline const ::ignition::msgs::Pose& Model::pose() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Model.pose)
  return _internal_pose();
}
inline void Model::unsafe_arena_set_allocated_pose(
    ::ignition::msgs::Pose* pose) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose_);
  }
  pose_ = pose;
  if (pose) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Model.pose)
}
inline ::ignition::msgs::Pose* Model::release_pose() {
  
  ::ignition::msgs::Pose* temp = pose_;
  pose_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Pose* Model::unsafe_arena_release_pose() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Model.pose)
  
  ::ignition::msgs::Pose* temp = pose_;
  pose_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Pose* Model::_internal_mutable_pose() {
  
  if (pose_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Pose>(GetArenaForAllocation());
    pose_ = p;
  }
  return pose_;
}
inline ::ignition::msgs::Pose* Model::mutable_pose() {
  ::ignition::msgs::Pose* _msg = _internal_mutable_pose();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Model.pose)
  return _msg;
}
inline void Model::set_allocated_pose(::ignition::msgs::Pose* pose) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose_);
  }
  if (pose) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose));
    if (message_arena != submessage_arena) {
      pose = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, pose, submessage_arena);
    }
    
  } else {
    
  }
  pose_ = pose;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Model.pose)
}

// repeated .ignition.msgs.Joint joint = 6;
inline int Model::_internal_joint_size() const {
  return joint_.size();
}
inline int Model::joint_size() const {
  return _internal_joint_size();
}
inline ::ignition::msgs::Joint* Model::mutable_joint(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Model.joint)
  return joint_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Joint >*
Model::mutable_joint() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Model.joint)
  return &joint_;
}
inline const ::ignition::msgs::Joint& Model::_internal_joint(int index) const {
  return joint_.Get(index);
}
inline const ::ignition::msgs::Joint& Model::joint(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Model.joint)
  return _internal_joint(index);
}
inline ::ignition::msgs::Joint* Model::_internal_add_joint() {
  return joint_.Add();
}
inline ::ignition::msgs::Joint* Model::add_joint() {
  ::ignition::msgs::Joint* _add = _internal_add_joint();
  // @@protoc_insertion_point(field_add:ignition.msgs.Model.joint)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Joint >&
Model::joint() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Model.joint)
  return joint_;
}

// repeated .ignition.msgs.Link link = 7;
inline int Model::_internal_link_size() const {
  return link_.size();
}
inline int Model::link_size() const {
  return _internal_link_size();
}
inline ::ignition::msgs::Link* Model::mutable_link(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Model.link)
  return link_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Link >*
Model::mutable_link() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Model.link)
  return &link_;
}
inline const ::ignition::msgs::Link& Model::_internal_link(int index) const {
  return link_.Get(index);
}
inline const ::ignition::msgs::Link& Model::link(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Model.link)
  return _internal_link(index);
}
inline ::ignition::msgs::Link* Model::_internal_add_link() {
  return link_.Add();
}
inline ::ignition::msgs::Link* Model::add_link() {
  ::ignition::msgs::Link* _add = _internal_add_link();
  // @@protoc_insertion_point(field_add:ignition.msgs.Model.link)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Link >&
Model::link() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Model.link)
  return link_;
}

// bool deleted = 8;
inline void Model::clear_deleted() {
  deleted_ = false;
}
inline bool Model::_internal_deleted() const {
  return deleted_;
}
inline bool Model::deleted() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Model.deleted)
  return _internal_deleted();
}
inline void Model::_internal_set_deleted(bool value) {
  
  deleted_ = value;
}
inline void Model::set_deleted(bool value) {
  _internal_set_deleted(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Model.deleted)
}

// repeated .ignition.msgs.Visual visual = 9;
inline int Model::_internal_visual_size() const {
  return visual_.size();
}
inline int Model::visual_size() const {
  return _internal_visual_size();
}
inline ::ignition::msgs::Visual* Model::mutable_visual(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Model.visual)
  return visual_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Visual >*
Model::mutable_visual() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Model.visual)
  return &visual_;
}
inline const ::ignition::msgs::Visual& Model::_internal_visual(int index) const {
  return visual_.Get(index);
}
inline const ::ignition::msgs::Visual& Model::visual(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Model.visual)
  return _internal_visual(index);
}
inline ::ignition::msgs::Visual* Model::_internal_add_visual() {
  return visual_.Add();
}
inline ::ignition::msgs::Visual* Model::add_visual() {
  ::ignition::msgs::Visual* _add = _internal_add_visual();
  // @@protoc_insertion_point(field_add:ignition.msgs.Model.visual)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Visual >&
Model::visual() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Model.visual)
  return visual_;
}

// .ignition.msgs.Vector3d scale = 10;
inline bool Model::_internal_has_scale() const {
  return this != internal_default_instance() && scale_ != nullptr;
}
inline bool Model::has_scale() const {
  return _internal_has_scale();
}
inline const ::ignition::msgs::Vector3d& Model::_internal_scale() const {
  const ::ignition::msgs::Vector3d* p = scale_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Vector3d&>(
      ::ignition::msgs::_Vector3d_default_instance_);
}
inline const ::ignition::msgs::Vector3d& Model::scale() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Model.scale)
  return _internal_scale();
}
inline void Model::unsafe_arena_set_allocated_scale(
    ::ignition::msgs::Vector3d* scale) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(scale_);
  }
  scale_ = scale;
  if (scale) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Model.scale)
}
inline ::ignition::msgs::Vector3d* Model::release_scale() {
  
  ::ignition::msgs::Vector3d* temp = scale_;
  scale_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Vector3d* Model::unsafe_arena_release_scale() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Model.scale)
  
  ::ignition::msgs::Vector3d* temp = scale_;
  scale_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Vector3d* Model::_internal_mutable_scale() {
  
  if (scale_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Vector3d>(GetArenaForAllocation());
    scale_ = p;
  }
  return scale_;
}
inline ::ignition::msgs::Vector3d* Model::mutable_scale() {
  ::ignition::msgs::Vector3d* _msg = _internal_mutable_scale();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Model.scale)
  return _msg;
}
inline void Model::set_allocated_scale(::ignition::msgs::Vector3d* scale) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(scale_);
  }
  if (scale) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(scale));
    if (message_arena != submessage_arena) {
      scale = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, scale, submessage_arena);
    }
    
  } else {
    
  }
  scale_ = scale;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Model.scale)
}

// bool self_collide = 11;
inline void Model::clear_self_collide() {
  self_collide_ = false;
}
inline bool Model::_internal_self_collide() const {
  return self_collide_;
}
inline bool Model::self_collide() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Model.self_collide)
  return _internal_self_collide();
}
inline void Model::_internal_set_self_collide(bool value) {
  
  self_collide_ = value;
}
inline void Model::set_self_collide(bool value) {
  _internal_set_self_collide(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Model.self_collide)
}

// repeated .ignition.msgs.Model model = 12;
inline int Model::_internal_model_size() const {
  return model_.size();
}
inline int Model::model_size() const {
  return _internal_model_size();
}
inline void Model::clear_model() {
  model_.Clear();
}
inline ::ignition::msgs::Model* Model::mutable_model(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Model.model)
  return model_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Model >*
Model::mutable_model() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Model.model)
  return &model_;
}
inline const ::ignition::msgs::Model& Model::_internal_model(int index) const {
  return model_.Get(index);
}
inline const ::ignition::msgs::Model& Model::model(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Model.model)
  return _internal_model(index);
}
inline ::ignition::msgs::Model* Model::_internal_add_model() {
  return model_.Add();
}
inline ::ignition::msgs::Model* Model::add_model() {
  ::ignition::msgs::Model* _add = _internal_add_model();
  // @@protoc_insertion_point(field_add:ignition.msgs.Model.model)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Model >&
Model::model() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Model.model)
  return model_;
}

// .ignition.msgs.AxisAlignedBox bounding_box = 13;
inline bool Model::_internal_has_bounding_box() const {
  return this != internal_default_instance() && bounding_box_ != nullptr;
}
inline bool Model::has_bounding_box() const {
  return _internal_has_bounding_box();
}
inline const ::ignition::msgs::AxisAlignedBox& Model::_internal_bounding_box() const {
  const ::ignition::msgs::AxisAlignedBox* p = bounding_box_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::AxisAlignedBox&>(
      ::ignition::msgs::_AxisAlignedBox_default_instance_);
}
inline const ::ignition::msgs::AxisAlignedBox& Model::bounding_box() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Model.bounding_box)
  return _internal_bounding_box();
}
inline void Model::unsafe_arena_set_allocated_bounding_box(
    ::ignition::msgs::AxisAlignedBox* bounding_box) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(bounding_box_);
  }
  bounding_box_ = bounding_box;
  if (bounding_box) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Model.bounding_box)
}
inline ::ignition::msgs::AxisAlignedBox* Model::release_bounding_box() {
  
  ::ignition::msgs::AxisAlignedBox* temp = bounding_box_;
  bounding_box_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::AxisAlignedBox* Model::unsafe_arena_release_bounding_box() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Model.bounding_box)
  
  ::ignition::msgs::AxisAlignedBox* temp = bounding_box_;
  bounding_box_ = nullptr;
  return temp;
}
inline ::ignition::msgs::AxisAlignedBox* Model::_internal_mutable_bounding_box() {
  
  if (bounding_box_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::AxisAlignedBox>(GetArenaForAllocation());
    bounding_box_ = p;
  }
  return bounding_box_;
}
inline ::ignition::msgs::AxisAlignedBox* Model::mutable_bounding_box() {
  ::ignition::msgs::AxisAlignedBox* _msg = _internal_mutable_bounding_box();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Model.bounding_box)
  return _msg;
}
inline void Model::set_allocated_bounding_box(::ignition::msgs::AxisAlignedBox* bounding_box) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(bounding_box_);
  }
  if (bounding_box) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(bounding_box));
    if (message_arena != submessage_arena) {
      bounding_box = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, bounding_box, submessage_arena);
    }
    
  } else {
    
  }
  bounding_box_ = bounding_box;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Model.bounding_box)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef std::unique_ptr<Model> ModelUniquePtr;
typedef std::unique_ptr<const Model> ConstModelUniquePtr;
typedef std::shared_ptr<Model> ModelSharedPtr;
typedef std::shared_ptr<const Model> ConstModelSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fmodel_2eproto
