# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/diagnostics.proto

require 'ignition/msgs/time_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/diagnostics.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Diagnostics" do
      optional :header, :message, 1, "ignition.msgs.Header"
      repeated :time, :message, 2, "ignition.msgs.Diagnostics.DiagTime"
      optional :real_time, :message, 3, "ignition.msgs.Time"
      optional :sim_time, :message, 4, "ignition.msgs.Time"
      optional :real_time_factor, :double, 5
    end
    add_message "ignition.msgs.Diagnostics.DiagTime" do
      optional :name, :string, 1
      optional :elapsed, :message, 2, "ignition.msgs.Time"
      optional :wall, :message, 3, "ignition.msgs.Time"
    end
  end
end

module Ignition
  module Msgs
    Diagnostics = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Diagnostics").msgclass
    Diagnostics::DiagTime = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Diagnostics.DiagTime").msgclass
  end
end
