/*
 * Copyright (C) 2017 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "SceneProtos";

/// \ingroup ignition.msgs
/// \interface Scene
/// \brief A message containing a description of a scene

import "ignition/msgs/color.proto";
import "ignition/msgs/fog.proto";
import "ignition/msgs/sky.proto";
import "ignition/msgs/light.proto";
import "ignition/msgs/joint.proto";
import "ignition/msgs/material.proto";
import "ignition/msgs/model.proto";
import "ignition/msgs/header.proto";

message Scene
{
  /// \brief Optional header data
  Header header       = 1;

  string name         = 2;
  Color ambient       = 3;
  Color background    = 4;
  Sky sky             = 5;
  bool shadows        = 6;
  Fog fog             = 7;
  bool grid           = 8;

  repeated Model model         = 9;
  repeated Light light         = 10;
  repeated Joint joint         = 11;

  /// \brief Show/hide world origin indicator.
  bool origin_visual  = 12;

  /// \brief Shadow caster material script.
  Material.Script shadow_caster_material_script = 13;
}
