// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/any.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fany_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fany_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018001 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/generated_enum_reflection.h>
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/header.pb.h"
#include "ignition/msgs/color.pb.h"
#include "ignition/msgs/pose.pb.h"
#include "ignition/msgs/quaternion.pb.h"
#include "ignition/msgs/time.pb.h"
#include "ignition/msgs/vector3d.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fany_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fany_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fany_2eproto;
namespace ignition {
namespace msgs {
class Any;
struct AnyDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern AnyDefaultTypeInternal _Any_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::Any* Arena::CreateMaybeMessage<::ignition::msgs::Any>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

enum Any_ValueType : int {
  Any_ValueType_NONE = 0,
  Any_ValueType_DOUBLE = 1,
  Any_ValueType_INT32 = 2,
  Any_ValueType_STRING = 3,
  Any_ValueType_BOOLEAN = 4,
  Any_ValueType_VECTOR3D = 5,
  Any_ValueType_COLOR = 6,
  Any_ValueType_POSE3D = 7,
  Any_ValueType_QUATERNIOND = 8,
  Any_ValueType_TIME = 9,
  Any_ValueType_Any_ValueType_INT_MIN_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::min(),
  Any_ValueType_Any_ValueType_INT_MAX_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::max()
};
IGNITION_MSGS_VISIBLE bool Any_ValueType_IsValid(int value);
constexpr Any_ValueType Any_ValueType_ValueType_MIN = Any_ValueType_NONE;
constexpr Any_ValueType Any_ValueType_ValueType_MAX = Any_ValueType_TIME;
constexpr int Any_ValueType_ValueType_ARRAYSIZE = Any_ValueType_ValueType_MAX + 1;

IGNITION_MSGS_VISIBLE const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor* Any_ValueType_descriptor();
template<typename T>
inline const std::string& Any_ValueType_Name(T enum_t_value) {
  static_assert(::std::is_same<T, Any_ValueType>::value ||
    ::std::is_integral<T>::value,
    "Incorrect type passed to function Any_ValueType_Name.");
  return ::PROTOBUF_NAMESPACE_ID::internal::NameOfEnum(
    Any_ValueType_descriptor(), enum_t_value);
}
inline bool Any_ValueType_Parse(
    ::PROTOBUF_NAMESPACE_ID::ConstStringParam name, Any_ValueType* value) {
  return ::PROTOBUF_NAMESPACE_ID::internal::ParseNamedEnum<Any_ValueType>(
    Any_ValueType_descriptor(), name, value);
}
// ===================================================================

class IGNITION_MSGS_VISIBLE Any final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.Any) */ {
 public:
  inline Any() : Any(nullptr) {}
  ~Any() override;
  explicit constexpr Any(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  Any(const Any& from);
  Any(Any&& from) noexcept
    : Any() {
    *this = ::std::move(from);
  }

  inline Any& operator=(const Any& from) {
    CopyFrom(from);
    return *this;
  }
  inline Any& operator=(Any&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Any& default_instance() {
    return *internal_default_instance();
  }
  enum ValueCase {
    kDoubleValue = 3,
    kIntValue = 4,
    kStringValue = 5,
    kBoolValue = 6,
    kVector3DValue = 7,
    kColorValue = 8,
    kPose3DValue = 9,
    kQuaternionValue = 10,
    kTimeValue = 11,
    VALUE_NOT_SET = 0,
  };

  static inline const Any* internal_default_instance() {
    return reinterpret_cast<const Any*>(
               &_Any_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(Any& a, Any& b) {
    a.Swap(&b);
  }
  inline void Swap(Any* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Any* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline Any* New() const final {
    return new Any();
  }

  Any* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<Any>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const Any& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const Any& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Any* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.Any";
  }
  protected:
  explicit Any(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  typedef Any_ValueType ValueType;
  static constexpr ValueType NONE =
    Any_ValueType_NONE;
  static constexpr ValueType DOUBLE =
    Any_ValueType_DOUBLE;
  static constexpr ValueType INT32 =
    Any_ValueType_INT32;
  static constexpr ValueType STRING =
    Any_ValueType_STRING;
  static constexpr ValueType BOOLEAN =
    Any_ValueType_BOOLEAN;
  static constexpr ValueType VECTOR3D =
    Any_ValueType_VECTOR3D;
  static constexpr ValueType COLOR =
    Any_ValueType_COLOR;
  static constexpr ValueType POSE3D =
    Any_ValueType_POSE3D;
  static constexpr ValueType QUATERNIOND =
    Any_ValueType_QUATERNIOND;
  static constexpr ValueType TIME =
    Any_ValueType_TIME;
  static inline bool ValueType_IsValid(int value) {
    return Any_ValueType_IsValid(value);
  }
  static constexpr ValueType ValueType_MIN =
    Any_ValueType_ValueType_MIN;
  static constexpr ValueType ValueType_MAX =
    Any_ValueType_ValueType_MAX;
  static constexpr int ValueType_ARRAYSIZE =
    Any_ValueType_ValueType_ARRAYSIZE;
  static inline const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor*
  ValueType_descriptor() {
    return Any_ValueType_descriptor();
  }
  template<typename T>
  static inline const std::string& ValueType_Name(T enum_t_value) {
    static_assert(::std::is_same<T, ValueType>::value ||
      ::std::is_integral<T>::value,
      "Incorrect type passed to function ValueType_Name.");
    return Any_ValueType_Name(enum_t_value);
  }
  static inline bool ValueType_Parse(::PROTOBUF_NAMESPACE_ID::ConstStringParam name,
      ValueType* value) {
    return Any_ValueType_Parse(name, value);
  }

  // accessors -------------------------------------------------------

  enum : int {
    kHeaderFieldNumber = 1,
    kTypeFieldNumber = 2,
    kDoubleValueFieldNumber = 3,
    kIntValueFieldNumber = 4,
    kStringValueFieldNumber = 5,
    kBoolValueFieldNumber = 6,
    kVector3DValueFieldNumber = 7,
    kColorValueFieldNumber = 8,
    kPose3DValueFieldNumber = 9,
    kQuaternionValueFieldNumber = 10,
    kTimeValueFieldNumber = 11,
  };
  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // .ignition.msgs.Any.ValueType type = 2;
  void clear_type();
  ::ignition::msgs::Any_ValueType type() const;
  void set_type(::ignition::msgs::Any_ValueType value);
  private:
  ::ignition::msgs::Any_ValueType _internal_type() const;
  void _internal_set_type(::ignition::msgs::Any_ValueType value);
  public:

  // double double_value = 3;
  bool has_double_value() const;
  private:
  bool _internal_has_double_value() const;
  public:
  void clear_double_value();
  double double_value() const;
  void set_double_value(double value);
  private:
  double _internal_double_value() const;
  void _internal_set_double_value(double value);
  public:

  // int32 int_value = 4;
  bool has_int_value() const;
  private:
  bool _internal_has_int_value() const;
  public:
  void clear_int_value();
  ::PROTOBUF_NAMESPACE_ID::int32 int_value() const;
  void set_int_value(::PROTOBUF_NAMESPACE_ID::int32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::int32 _internal_int_value() const;
  void _internal_set_int_value(::PROTOBUF_NAMESPACE_ID::int32 value);
  public:

  // string string_value = 5;
  bool has_string_value() const;
  private:
  bool _internal_has_string_value() const;
  public:
  void clear_string_value();
  const std::string& string_value() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_string_value(ArgT0&& arg0, ArgT... args);
  std::string* mutable_string_value();
  PROTOBUF_MUST_USE_RESULT std::string* release_string_value();
  void set_allocated_string_value(std::string* string_value);
  private:
  const std::string& _internal_string_value() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_string_value(const std::string& value);
  std::string* _internal_mutable_string_value();
  public:

  // bool bool_value = 6;
  bool has_bool_value() const;
  private:
  bool _internal_has_bool_value() const;
  public:
  void clear_bool_value();
  bool bool_value() const;
  void set_bool_value(bool value);
  private:
  bool _internal_bool_value() const;
  void _internal_set_bool_value(bool value);
  public:

  // .ignition.msgs.Vector3d vector3d_value = 7;
  bool has_vector3d_value() const;
  private:
  bool _internal_has_vector3d_value() const;
  public:
  void clear_vector3d_value();
  const ::ignition::msgs::Vector3d& vector3d_value() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Vector3d* release_vector3d_value();
  ::ignition::msgs::Vector3d* mutable_vector3d_value();
  void set_allocated_vector3d_value(::ignition::msgs::Vector3d* vector3d_value);
  private:
  const ::ignition::msgs::Vector3d& _internal_vector3d_value() const;
  ::ignition::msgs::Vector3d* _internal_mutable_vector3d_value();
  public:
  void unsafe_arena_set_allocated_vector3d_value(
      ::ignition::msgs::Vector3d* vector3d_value);
  ::ignition::msgs::Vector3d* unsafe_arena_release_vector3d_value();

  // .ignition.msgs.Color color_value = 8;
  bool has_color_value() const;
  private:
  bool _internal_has_color_value() const;
  public:
  void clear_color_value();
  const ::ignition::msgs::Color& color_value() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Color* release_color_value();
  ::ignition::msgs::Color* mutable_color_value();
  void set_allocated_color_value(::ignition::msgs::Color* color_value);
  private:
  const ::ignition::msgs::Color& _internal_color_value() const;
  ::ignition::msgs::Color* _internal_mutable_color_value();
  public:
  void unsafe_arena_set_allocated_color_value(
      ::ignition::msgs::Color* color_value);
  ::ignition::msgs::Color* unsafe_arena_release_color_value();

  // .ignition.msgs.Pose pose3d_value = 9;
  bool has_pose3d_value() const;
  private:
  bool _internal_has_pose3d_value() const;
  public:
  void clear_pose3d_value();
  const ::ignition::msgs::Pose& pose3d_value() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Pose* release_pose3d_value();
  ::ignition::msgs::Pose* mutable_pose3d_value();
  void set_allocated_pose3d_value(::ignition::msgs::Pose* pose3d_value);
  private:
  const ::ignition::msgs::Pose& _internal_pose3d_value() const;
  ::ignition::msgs::Pose* _internal_mutable_pose3d_value();
  public:
  void unsafe_arena_set_allocated_pose3d_value(
      ::ignition::msgs::Pose* pose3d_value);
  ::ignition::msgs::Pose* unsafe_arena_release_pose3d_value();

  // .ignition.msgs.Quaternion quaternion_value = 10;
  bool has_quaternion_value() const;
  private:
  bool _internal_has_quaternion_value() const;
  public:
  void clear_quaternion_value();
  const ::ignition::msgs::Quaternion& quaternion_value() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Quaternion* release_quaternion_value();
  ::ignition::msgs::Quaternion* mutable_quaternion_value();
  void set_allocated_quaternion_value(::ignition::msgs::Quaternion* quaternion_value);
  private:
  const ::ignition::msgs::Quaternion& _internal_quaternion_value() const;
  ::ignition::msgs::Quaternion* _internal_mutable_quaternion_value();
  public:
  void unsafe_arena_set_allocated_quaternion_value(
      ::ignition::msgs::Quaternion* quaternion_value);
  ::ignition::msgs::Quaternion* unsafe_arena_release_quaternion_value();

  // .ignition.msgs.Time time_value = 11;
  bool has_time_value() const;
  private:
  bool _internal_has_time_value() const;
  public:
  void clear_time_value();
  const ::ignition::msgs::Time& time_value() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Time* release_time_value();
  ::ignition::msgs::Time* mutable_time_value();
  void set_allocated_time_value(::ignition::msgs::Time* time_value);
  private:
  const ::ignition::msgs::Time& _internal_time_value() const;
  ::ignition::msgs::Time* _internal_mutable_time_value();
  public:
  void unsafe_arena_set_allocated_time_value(
      ::ignition::msgs::Time* time_value);
  ::ignition::msgs::Time* unsafe_arena_release_time_value();

  void clear_value();
  ValueCase value_case() const;
  // @@protoc_insertion_point(class_scope:ignition.msgs.Any)
 private:
  class _Internal;
  void set_has_double_value();
  void set_has_int_value();
  void set_has_string_value();
  void set_has_bool_value();
  void set_has_vector3d_value();
  void set_has_color_value();
  void set_has_pose3d_value();
  void set_has_quaternion_value();
  void set_has_time_value();

  inline bool has_value() const;
  inline void clear_has_value();

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::ignition::msgs::Header* header_;
  int type_;
  union ValueUnion {
    constexpr ValueUnion() : _constinit_{} {}
      ::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized _constinit_;
    double double_value_;
    ::PROTOBUF_NAMESPACE_ID::int32 int_value_;
    ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr string_value_;
    bool bool_value_;
    ::ignition::msgs::Vector3d* vector3d_value_;
    ::ignition::msgs::Color* color_value_;
    ::ignition::msgs::Pose* pose3d_value_;
    ::ignition::msgs::Quaternion* quaternion_value_;
    ::ignition::msgs::Time* time_value_;
  } value_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  ::PROTOBUF_NAMESPACE_ID::uint32 _oneof_case_[1];

  friend struct ::TableStruct_ignition_2fmsgs_2fany_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// Any

// .ignition.msgs.Header header = 1;
inline bool Any::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool Any::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& Any::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& Any::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Any.header)
  return _internal_header();
}
inline void Any::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Any.header)
}
inline ::ignition::msgs::Header* Any::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* Any::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Any.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* Any::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* Any::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Any.header)
  return _msg;
}
inline void Any::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Any.header)
}

// .ignition.msgs.Any.ValueType type = 2;
inline void Any::clear_type() {
  type_ = 0;
}
inline ::ignition::msgs::Any_ValueType Any::_internal_type() const {
  return static_cast< ::ignition::msgs::Any_ValueType >(type_);
}
inline ::ignition::msgs::Any_ValueType Any::type() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Any.type)
  return _internal_type();
}
inline void Any::_internal_set_type(::ignition::msgs::Any_ValueType value) {
  
  type_ = value;
}
inline void Any::set_type(::ignition::msgs::Any_ValueType value) {
  _internal_set_type(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Any.type)
}

// double double_value = 3;
inline bool Any::_internal_has_double_value() const {
  return value_case() == kDoubleValue;
}
inline bool Any::has_double_value() const {
  return _internal_has_double_value();
}
inline void Any::set_has_double_value() {
  _oneof_case_[0] = kDoubleValue;
}
inline void Any::clear_double_value() {
  if (_internal_has_double_value()) {
    value_.double_value_ = 0;
    clear_has_value();
  }
}
inline double Any::_internal_double_value() const {
  if (_internal_has_double_value()) {
    return value_.double_value_;
  }
  return 0;
}
inline void Any::_internal_set_double_value(double value) {
  if (!_internal_has_double_value()) {
    clear_value();
    set_has_double_value();
  }
  value_.double_value_ = value;
}
inline double Any::double_value() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Any.double_value)
  return _internal_double_value();
}
inline void Any::set_double_value(double value) {
  _internal_set_double_value(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Any.double_value)
}

// int32 int_value = 4;
inline bool Any::_internal_has_int_value() const {
  return value_case() == kIntValue;
}
inline bool Any::has_int_value() const {
  return _internal_has_int_value();
}
inline void Any::set_has_int_value() {
  _oneof_case_[0] = kIntValue;
}
inline void Any::clear_int_value() {
  if (_internal_has_int_value()) {
    value_.int_value_ = 0;
    clear_has_value();
  }
}
inline ::PROTOBUF_NAMESPACE_ID::int32 Any::_internal_int_value() const {
  if (_internal_has_int_value()) {
    return value_.int_value_;
  }
  return 0;
}
inline void Any::_internal_set_int_value(::PROTOBUF_NAMESPACE_ID::int32 value) {
  if (!_internal_has_int_value()) {
    clear_value();
    set_has_int_value();
  }
  value_.int_value_ = value;
}
inline ::PROTOBUF_NAMESPACE_ID::int32 Any::int_value() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Any.int_value)
  return _internal_int_value();
}
inline void Any::set_int_value(::PROTOBUF_NAMESPACE_ID::int32 value) {
  _internal_set_int_value(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Any.int_value)
}

// string string_value = 5;
inline bool Any::_internal_has_string_value() const {
  return value_case() == kStringValue;
}
inline bool Any::has_string_value() const {
  return _internal_has_string_value();
}
inline void Any::set_has_string_value() {
  _oneof_case_[0] = kStringValue;
}
inline void Any::clear_string_value() {
  if (_internal_has_string_value()) {
    value_.string_value_.Destroy(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
    clear_has_value();
  }
}
inline const std::string& Any::string_value() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Any.string_value)
  return _internal_string_value();
}
template <typename ArgT0, typename... ArgT>
inline void Any::set_string_value(ArgT0&& arg0, ArgT... args) {
  if (!_internal_has_string_value()) {
    clear_value();
    set_has_string_value();
    value_.string_value_.UnsafeSetDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited());
  }
  value_.string_value_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Any.string_value)
}
inline std::string* Any::mutable_string_value() {
  std::string* _s = _internal_mutable_string_value();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Any.string_value)
  return _s;
}
inline const std::string& Any::_internal_string_value() const {
  if (_internal_has_string_value()) {
    return value_.string_value_.Get();
  }
  return ::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited();
}
inline void Any::_internal_set_string_value(const std::string& value) {
  if (!_internal_has_string_value()) {
    clear_value();
    set_has_string_value();
    value_.string_value_.UnsafeSetDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited());
  }
  value_.string_value_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Any::_internal_mutable_string_value() {
  if (!_internal_has_string_value()) {
    clear_value();
    set_has_string_value();
    value_.string_value_.UnsafeSetDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited());
  }
  return value_.string_value_.Mutable(
      ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Any::release_string_value() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Any.string_value)
  if (_internal_has_string_value()) {
    clear_has_value();
    return value_.string_value_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
  } else {
    return nullptr;
  }
}
inline void Any::set_allocated_string_value(std::string* string_value) {
  if (has_value()) {
    clear_value();
  }
  if (string_value != nullptr) {
    set_has_string_value();
    value_.string_value_.UnsafeSetDefault(string_value);
    ::PROTOBUF_NAMESPACE_ID::Arena* arena = GetArenaForAllocation();
    if (arena != nullptr) {
      arena->Own(string_value);
    }
  }
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Any.string_value)
}

// bool bool_value = 6;
inline bool Any::_internal_has_bool_value() const {
  return value_case() == kBoolValue;
}
inline bool Any::has_bool_value() const {
  return _internal_has_bool_value();
}
inline void Any::set_has_bool_value() {
  _oneof_case_[0] = kBoolValue;
}
inline void Any::clear_bool_value() {
  if (_internal_has_bool_value()) {
    value_.bool_value_ = false;
    clear_has_value();
  }
}
inline bool Any::_internal_bool_value() const {
  if (_internal_has_bool_value()) {
    return value_.bool_value_;
  }
  return false;
}
inline void Any::_internal_set_bool_value(bool value) {
  if (!_internal_has_bool_value()) {
    clear_value();
    set_has_bool_value();
  }
  value_.bool_value_ = value;
}
inline bool Any::bool_value() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Any.bool_value)
  return _internal_bool_value();
}
inline void Any::set_bool_value(bool value) {
  _internal_set_bool_value(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Any.bool_value)
}

// .ignition.msgs.Vector3d vector3d_value = 7;
inline bool Any::_internal_has_vector3d_value() const {
  return value_case() == kVector3DValue;
}
inline bool Any::has_vector3d_value() const {
  return _internal_has_vector3d_value();
}
inline void Any::set_has_vector3d_value() {
  _oneof_case_[0] = kVector3DValue;
}
inline ::ignition::msgs::Vector3d* Any::release_vector3d_value() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Any.vector3d_value)
  if (_internal_has_vector3d_value()) {
    clear_has_value();
      ::ignition::msgs::Vector3d* temp = value_.vector3d_value_;
    if (GetArenaForAllocation() != nullptr) {
      temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
    }
    value_.vector3d_value_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline const ::ignition::msgs::Vector3d& Any::_internal_vector3d_value() const {
  return _internal_has_vector3d_value()
      ? *value_.vector3d_value_
      : reinterpret_cast< ::ignition::msgs::Vector3d&>(::ignition::msgs::_Vector3d_default_instance_);
}
inline const ::ignition::msgs::Vector3d& Any::vector3d_value() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Any.vector3d_value)
  return _internal_vector3d_value();
}
inline ::ignition::msgs::Vector3d* Any::unsafe_arena_release_vector3d_value() {
  // @@protoc_insertion_point(field_unsafe_arena_release:ignition.msgs.Any.vector3d_value)
  if (_internal_has_vector3d_value()) {
    clear_has_value();
    ::ignition::msgs::Vector3d* temp = value_.vector3d_value_;
    value_.vector3d_value_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline void Any::unsafe_arena_set_allocated_vector3d_value(::ignition::msgs::Vector3d* vector3d_value) {
  clear_value();
  if (vector3d_value) {
    set_has_vector3d_value();
    value_.vector3d_value_ = vector3d_value;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Any.vector3d_value)
}
inline ::ignition::msgs::Vector3d* Any::_internal_mutable_vector3d_value() {
  if (!_internal_has_vector3d_value()) {
    clear_value();
    set_has_vector3d_value();
    value_.vector3d_value_ = CreateMaybeMessage< ::ignition::msgs::Vector3d >(GetArenaForAllocation());
  }
  return value_.vector3d_value_;
}
inline ::ignition::msgs::Vector3d* Any::mutable_vector3d_value() {
  ::ignition::msgs::Vector3d* _msg = _internal_mutable_vector3d_value();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Any.vector3d_value)
  return _msg;
}

// .ignition.msgs.Color color_value = 8;
inline bool Any::_internal_has_color_value() const {
  return value_case() == kColorValue;
}
inline bool Any::has_color_value() const {
  return _internal_has_color_value();
}
inline void Any::set_has_color_value() {
  _oneof_case_[0] = kColorValue;
}
inline ::ignition::msgs::Color* Any::release_color_value() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Any.color_value)
  if (_internal_has_color_value()) {
    clear_has_value();
      ::ignition::msgs::Color* temp = value_.color_value_;
    if (GetArenaForAllocation() != nullptr) {
      temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
    }
    value_.color_value_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline const ::ignition::msgs::Color& Any::_internal_color_value() const {
  return _internal_has_color_value()
      ? *value_.color_value_
      : reinterpret_cast< ::ignition::msgs::Color&>(::ignition::msgs::_Color_default_instance_);
}
inline const ::ignition::msgs::Color& Any::color_value() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Any.color_value)
  return _internal_color_value();
}
inline ::ignition::msgs::Color* Any::unsafe_arena_release_color_value() {
  // @@protoc_insertion_point(field_unsafe_arena_release:ignition.msgs.Any.color_value)
  if (_internal_has_color_value()) {
    clear_has_value();
    ::ignition::msgs::Color* temp = value_.color_value_;
    value_.color_value_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline void Any::unsafe_arena_set_allocated_color_value(::ignition::msgs::Color* color_value) {
  clear_value();
  if (color_value) {
    set_has_color_value();
    value_.color_value_ = color_value;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Any.color_value)
}
inline ::ignition::msgs::Color* Any::_internal_mutable_color_value() {
  if (!_internal_has_color_value()) {
    clear_value();
    set_has_color_value();
    value_.color_value_ = CreateMaybeMessage< ::ignition::msgs::Color >(GetArenaForAllocation());
  }
  return value_.color_value_;
}
inline ::ignition::msgs::Color* Any::mutable_color_value() {
  ::ignition::msgs::Color* _msg = _internal_mutable_color_value();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Any.color_value)
  return _msg;
}

// .ignition.msgs.Pose pose3d_value = 9;
inline bool Any::_internal_has_pose3d_value() const {
  return value_case() == kPose3DValue;
}
inline bool Any::has_pose3d_value() const {
  return _internal_has_pose3d_value();
}
inline void Any::set_has_pose3d_value() {
  _oneof_case_[0] = kPose3DValue;
}
inline ::ignition::msgs::Pose* Any::release_pose3d_value() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Any.pose3d_value)
  if (_internal_has_pose3d_value()) {
    clear_has_value();
      ::ignition::msgs::Pose* temp = value_.pose3d_value_;
    if (GetArenaForAllocation() != nullptr) {
      temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
    }
    value_.pose3d_value_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline const ::ignition::msgs::Pose& Any::_internal_pose3d_value() const {
  return _internal_has_pose3d_value()
      ? *value_.pose3d_value_
      : reinterpret_cast< ::ignition::msgs::Pose&>(::ignition::msgs::_Pose_default_instance_);
}
inline const ::ignition::msgs::Pose& Any::pose3d_value() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Any.pose3d_value)
  return _internal_pose3d_value();
}
inline ::ignition::msgs::Pose* Any::unsafe_arena_release_pose3d_value() {
  // @@protoc_insertion_point(field_unsafe_arena_release:ignition.msgs.Any.pose3d_value)
  if (_internal_has_pose3d_value()) {
    clear_has_value();
    ::ignition::msgs::Pose* temp = value_.pose3d_value_;
    value_.pose3d_value_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline void Any::unsafe_arena_set_allocated_pose3d_value(::ignition::msgs::Pose* pose3d_value) {
  clear_value();
  if (pose3d_value) {
    set_has_pose3d_value();
    value_.pose3d_value_ = pose3d_value;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Any.pose3d_value)
}
inline ::ignition::msgs::Pose* Any::_internal_mutable_pose3d_value() {
  if (!_internal_has_pose3d_value()) {
    clear_value();
    set_has_pose3d_value();
    value_.pose3d_value_ = CreateMaybeMessage< ::ignition::msgs::Pose >(GetArenaForAllocation());
  }
  return value_.pose3d_value_;
}
inline ::ignition::msgs::Pose* Any::mutable_pose3d_value() {
  ::ignition::msgs::Pose* _msg = _internal_mutable_pose3d_value();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Any.pose3d_value)
  return _msg;
}

// .ignition.msgs.Quaternion quaternion_value = 10;
inline bool Any::_internal_has_quaternion_value() const {
  return value_case() == kQuaternionValue;
}
inline bool Any::has_quaternion_value() const {
  return _internal_has_quaternion_value();
}
inline void Any::set_has_quaternion_value() {
  _oneof_case_[0] = kQuaternionValue;
}
inline ::ignition::msgs::Quaternion* Any::release_quaternion_value() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Any.quaternion_value)
  if (_internal_has_quaternion_value()) {
    clear_has_value();
      ::ignition::msgs::Quaternion* temp = value_.quaternion_value_;
    if (GetArenaForAllocation() != nullptr) {
      temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
    }
    value_.quaternion_value_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline const ::ignition::msgs::Quaternion& Any::_internal_quaternion_value() const {
  return _internal_has_quaternion_value()
      ? *value_.quaternion_value_
      : reinterpret_cast< ::ignition::msgs::Quaternion&>(::ignition::msgs::_Quaternion_default_instance_);
}
inline const ::ignition::msgs::Quaternion& Any::quaternion_value() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Any.quaternion_value)
  return _internal_quaternion_value();
}
inline ::ignition::msgs::Quaternion* Any::unsafe_arena_release_quaternion_value() {
  // @@protoc_insertion_point(field_unsafe_arena_release:ignition.msgs.Any.quaternion_value)
  if (_internal_has_quaternion_value()) {
    clear_has_value();
    ::ignition::msgs::Quaternion* temp = value_.quaternion_value_;
    value_.quaternion_value_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline void Any::unsafe_arena_set_allocated_quaternion_value(::ignition::msgs::Quaternion* quaternion_value) {
  clear_value();
  if (quaternion_value) {
    set_has_quaternion_value();
    value_.quaternion_value_ = quaternion_value;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Any.quaternion_value)
}
inline ::ignition::msgs::Quaternion* Any::_internal_mutable_quaternion_value() {
  if (!_internal_has_quaternion_value()) {
    clear_value();
    set_has_quaternion_value();
    value_.quaternion_value_ = CreateMaybeMessage< ::ignition::msgs::Quaternion >(GetArenaForAllocation());
  }
  return value_.quaternion_value_;
}
inline ::ignition::msgs::Quaternion* Any::mutable_quaternion_value() {
  ::ignition::msgs::Quaternion* _msg = _internal_mutable_quaternion_value();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Any.quaternion_value)
  return _msg;
}

// .ignition.msgs.Time time_value = 11;
inline bool Any::_internal_has_time_value() const {
  return value_case() == kTimeValue;
}
inline bool Any::has_time_value() const {
  return _internal_has_time_value();
}
inline void Any::set_has_time_value() {
  _oneof_case_[0] = kTimeValue;
}
inline ::ignition::msgs::Time* Any::release_time_value() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Any.time_value)
  if (_internal_has_time_value()) {
    clear_has_value();
      ::ignition::msgs::Time* temp = value_.time_value_;
    if (GetArenaForAllocation() != nullptr) {
      temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
    }
    value_.time_value_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline const ::ignition::msgs::Time& Any::_internal_time_value() const {
  return _internal_has_time_value()
      ? *value_.time_value_
      : reinterpret_cast< ::ignition::msgs::Time&>(::ignition::msgs::_Time_default_instance_);
}
inline const ::ignition::msgs::Time& Any::time_value() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Any.time_value)
  return _internal_time_value();
}
inline ::ignition::msgs::Time* Any::unsafe_arena_release_time_value() {
  // @@protoc_insertion_point(field_unsafe_arena_release:ignition.msgs.Any.time_value)
  if (_internal_has_time_value()) {
    clear_has_value();
    ::ignition::msgs::Time* temp = value_.time_value_;
    value_.time_value_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline void Any::unsafe_arena_set_allocated_time_value(::ignition::msgs::Time* time_value) {
  clear_value();
  if (time_value) {
    set_has_time_value();
    value_.time_value_ = time_value;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Any.time_value)
}
inline ::ignition::msgs::Time* Any::_internal_mutable_time_value() {
  if (!_internal_has_time_value()) {
    clear_value();
    set_has_time_value();
    value_.time_value_ = CreateMaybeMessage< ::ignition::msgs::Time >(GetArenaForAllocation());
  }
  return value_.time_value_;
}
inline ::ignition::msgs::Time* Any::mutable_time_value() {
  ::ignition::msgs::Time* _msg = _internal_mutable_time_value();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Any.time_value)
  return _msg;
}

inline bool Any::has_value() const {
  return value_case() != VALUE_NOT_SET;
}
inline void Any::clear_has_value() {
  _oneof_case_[0] = VALUE_NOT_SET;
}
inline Any::ValueCase Any::value_case() const {
  return Any::ValueCase(_oneof_case_[0]);
}
#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef std::unique_ptr<Any> AnyUniquePtr;
typedef std::unique_ptr<const Any> ConstAnyUniquePtr;
typedef std::shared_ptr<Any> AnySharedPtr;
typedef std::shared_ptr<const Any> ConstAnySharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

PROTOBUF_NAMESPACE_OPEN

template <> struct is_proto_enum< ::ignition::msgs::Any_ValueType> : ::std::true_type {};
template <>
inline const EnumDescriptor* GetEnumDescriptor< ::ignition::msgs::Any_ValueType>() {
  return ::ignition::msgs::Any_ValueType_descriptor();
}

PROTOBUF_NAMESPACE_CLOSE

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fany_2eproto
