# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/topic_info.proto

require 'ignition/msgs/publish_pb'
require 'ignition/msgs/subscribe_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/topic_info.proto", :syntax => :proto3) do
    add_message "ignition.msgs.TopicInfo" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :msg_type, :string, 2
      repeated :publisher, :message, 3, "ignition.msgs.Publish"
      repeated :subscriber, :message, 4, "ignition.msgs.Subscribe"
    end
  end
end

module Ignition
  module Msgs
    TopicInfo = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.TopicInfo").msgclass
  end
end
