// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/log_control.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2flog_5fcontrol_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2flog_5fcontrol_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018001 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/header.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2flog_5fcontrol_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2flog_5fcontrol_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2flog_5fcontrol_2eproto;
namespace ignition {
namespace msgs {
class LogControl;
struct LogControlDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern LogControlDefaultTypeInternal _LogControl_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::LogControl* Arena::CreateMaybeMessage<::ignition::msgs::LogControl>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

// ===================================================================

class IGNITION_MSGS_VISIBLE LogControl final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.LogControl) */ {
 public:
  inline LogControl() : LogControl(nullptr) {}
  ~LogControl() override;
  explicit constexpr LogControl(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  LogControl(const LogControl& from);
  LogControl(LogControl&& from) noexcept
    : LogControl() {
    *this = ::std::move(from);
  }

  inline LogControl& operator=(const LogControl& from) {
    CopyFrom(from);
    return *this;
  }
  inline LogControl& operator=(LogControl&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const LogControl& default_instance() {
    return *internal_default_instance();
  }
  static inline const LogControl* internal_default_instance() {
    return reinterpret_cast<const LogControl*>(
               &_LogControl_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(LogControl& a, LogControl& b) {
    a.Swap(&b);
  }
  inline void Swap(LogControl* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(LogControl* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline LogControl* New() const final {
    return new LogControl();
  }

  LogControl* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<LogControl>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const LogControl& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const LogControl& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(LogControl* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.LogControl";
  }
  protected:
  explicit LogControl(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kBasePathFieldNumber = 5,
    kEncodingFieldNumber = 6,
    kRecordResourcesFieldNumber = 7,
    kHeaderFieldNumber = 1,
    kStartFieldNumber = 2,
    kStopFieldNumber = 3,
    kPausedFieldNumber = 4,
  };
  // string base_path = 5;
  void clear_base_path();
  const std::string& base_path() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_base_path(ArgT0&& arg0, ArgT... args);
  std::string* mutable_base_path();
  PROTOBUF_MUST_USE_RESULT std::string* release_base_path();
  void set_allocated_base_path(std::string* base_path);
  private:
  const std::string& _internal_base_path() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_base_path(const std::string& value);
  std::string* _internal_mutable_base_path();
  public:

  // string encoding = 6;
  void clear_encoding();
  const std::string& encoding() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_encoding(ArgT0&& arg0, ArgT... args);
  std::string* mutable_encoding();
  PROTOBUF_MUST_USE_RESULT std::string* release_encoding();
  void set_allocated_encoding(std::string* encoding);
  private:
  const std::string& _internal_encoding() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_encoding(const std::string& value);
  std::string* _internal_mutable_encoding();
  public:

  // string record_resources = 7;
  void clear_record_resources();
  const std::string& record_resources() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_record_resources(ArgT0&& arg0, ArgT... args);
  std::string* mutable_record_resources();
  PROTOBUF_MUST_USE_RESULT std::string* release_record_resources();
  void set_allocated_record_resources(std::string* record_resources);
  private:
  const std::string& _internal_record_resources() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_record_resources(const std::string& value);
  std::string* _internal_mutable_record_resources();
  public:

  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // bool start = 2;
  void clear_start();
  bool start() const;
  void set_start(bool value);
  private:
  bool _internal_start() const;
  void _internal_set_start(bool value);
  public:

  // bool stop = 3;
  void clear_stop();
  bool stop() const;
  void set_stop(bool value);
  private:
  bool _internal_stop() const;
  void _internal_set_stop(bool value);
  public:

  // bool paused = 4;
  void clear_paused();
  bool paused() const;
  void set_paused(bool value);
  private:
  bool _internal_paused() const;
  void _internal_set_paused(bool value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.LogControl)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr base_path_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr encoding_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr record_resources_;
  ::ignition::msgs::Header* header_;
  bool start_;
  bool stop_;
  bool paused_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2flog_5fcontrol_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// LogControl

// .ignition.msgs.Header header = 1;
inline bool LogControl::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool LogControl::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& LogControl::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& LogControl::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.LogControl.header)
  return _internal_header();
}
inline void LogControl::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.LogControl.header)
}
inline ::ignition::msgs::Header* LogControl::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* LogControl::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.LogControl.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* LogControl::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* LogControl::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.LogControl.header)
  return _msg;
}
inline void LogControl::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.LogControl.header)
}

// bool start = 2;
inline void LogControl::clear_start() {
  start_ = false;
}
inline bool LogControl::_internal_start() const {
  return start_;
}
inline bool LogControl::start() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.LogControl.start)
  return _internal_start();
}
inline void LogControl::_internal_set_start(bool value) {
  
  start_ = value;
}
inline void LogControl::set_start(bool value) {
  _internal_set_start(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.LogControl.start)
}

// bool stop = 3;
inline void LogControl::clear_stop() {
  stop_ = false;
}
inline bool LogControl::_internal_stop() const {
  return stop_;
}
inline bool LogControl::stop() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.LogControl.stop)
  return _internal_stop();
}
inline void LogControl::_internal_set_stop(bool value) {
  
  stop_ = value;
}
inline void LogControl::set_stop(bool value) {
  _internal_set_stop(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.LogControl.stop)
}

// bool paused = 4;
inline void LogControl::clear_paused() {
  paused_ = false;
}
inline bool LogControl::_internal_paused() const {
  return paused_;
}
inline bool LogControl::paused() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.LogControl.paused)
  return _internal_paused();
}
inline void LogControl::_internal_set_paused(bool value) {
  
  paused_ = value;
}
inline void LogControl::set_paused(bool value) {
  _internal_set_paused(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.LogControl.paused)
}

// string base_path = 5;
inline void LogControl::clear_base_path() {
  base_path_.ClearToEmpty();
}
inline const std::string& LogControl::base_path() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.LogControl.base_path)
  return _internal_base_path();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void LogControl::set_base_path(ArgT0&& arg0, ArgT... args) {
 
 base_path_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.LogControl.base_path)
}
inline std::string* LogControl::mutable_base_path() {
  std::string* _s = _internal_mutable_base_path();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.LogControl.base_path)
  return _s;
}
inline const std::string& LogControl::_internal_base_path() const {
  return base_path_.Get();
}
inline void LogControl::_internal_set_base_path(const std::string& value) {
  
  base_path_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* LogControl::_internal_mutable_base_path() {
  
  return base_path_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* LogControl::release_base_path() {
  // @@protoc_insertion_point(field_release:ignition.msgs.LogControl.base_path)
  return base_path_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void LogControl::set_allocated_base_path(std::string* base_path) {
  if (base_path != nullptr) {
    
  } else {
    
  }
  base_path_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), base_path,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.LogControl.base_path)
}

// string encoding = 6;
inline void LogControl::clear_encoding() {
  encoding_.ClearToEmpty();
}
inline const std::string& LogControl::encoding() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.LogControl.encoding)
  return _internal_encoding();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void LogControl::set_encoding(ArgT0&& arg0, ArgT... args) {
 
 encoding_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.LogControl.encoding)
}
inline std::string* LogControl::mutable_encoding() {
  std::string* _s = _internal_mutable_encoding();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.LogControl.encoding)
  return _s;
}
inline const std::string& LogControl::_internal_encoding() const {
  return encoding_.Get();
}
inline void LogControl::_internal_set_encoding(const std::string& value) {
  
  encoding_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* LogControl::_internal_mutable_encoding() {
  
  return encoding_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* LogControl::release_encoding() {
  // @@protoc_insertion_point(field_release:ignition.msgs.LogControl.encoding)
  return encoding_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void LogControl::set_allocated_encoding(std::string* encoding) {
  if (encoding != nullptr) {
    
  } else {
    
  }
  encoding_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), encoding,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.LogControl.encoding)
}

// string record_resources = 7;
inline void LogControl::clear_record_resources() {
  record_resources_.ClearToEmpty();
}
inline const std::string& LogControl::record_resources() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.LogControl.record_resources)
  return _internal_record_resources();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void LogControl::set_record_resources(ArgT0&& arg0, ArgT... args) {
 
 record_resources_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.LogControl.record_resources)
}
inline std::string* LogControl::mutable_record_resources() {
  std::string* _s = _internal_mutable_record_resources();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.LogControl.record_resources)
  return _s;
}
inline const std::string& LogControl::_internal_record_resources() const {
  return record_resources_.Get();
}
inline void LogControl::_internal_set_record_resources(const std::string& value) {
  
  record_resources_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* LogControl::_internal_mutable_record_resources() {
  
  return record_resources_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* LogControl::release_record_resources() {
  // @@protoc_insertion_point(field_release:ignition.msgs.LogControl.record_resources)
  return record_resources_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void LogControl::set_allocated_record_resources(std::string* record_resources) {
  if (record_resources != nullptr) {
    
  } else {
    
  }
  record_resources_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), record_resources,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.LogControl.record_resources)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef std::unique_ptr<LogControl> LogControlUniquePtr;
typedef std::unique_ptr<const LogControl> ConstLogControlUniquePtr;
typedef std::shared_ptr<LogControl> LogControlSharedPtr;
typedef std::shared_ptr<const LogControl> ConstLogControlSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2flog_5fcontrol_2eproto
