# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/pid.proto

require 'ignition/msgs/double_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/pid.proto", :syntax => :proto3) do
    add_message "ignition.msgs.PID" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :target_optional, :message, 2, "ignition.msgs.Double"
      optional :p_gain_optional, :message, 3, "ignition.msgs.Double"
      optional :i_gain_optional, :message, 4, "ignition.msgs.Double"
      optional :d_gain_optional, :message, 5, "ignition.msgs.Double"
      optional :i_max_optional, :message, 6, "ignition.msgs.Double"
      optional :i_min_optional, :message, 7, "ignition.msgs.Double"
      optional :limit_optional, :message, 8, "ignition.msgs.Double"
    end
  end
end

module Ignition
  module Msgs
    PID = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.PID").msgclass
  end
end
