// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/contact.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fcontact_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fcontact_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018001 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/entity.pb.h"
#include "ignition/msgs/vector3d.pb.h"
#include "ignition/msgs/joint_wrench.pb.h"
#include "ignition/msgs/header.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fcontact_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fcontact_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fcontact_2eproto;
namespace ignition {
namespace msgs {
class Contact;
struct ContactDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern ContactDefaultTypeInternal _Contact_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::Contact* Arena::CreateMaybeMessage<::ignition::msgs::Contact>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

// ===================================================================

class IGNITION_MSGS_VISIBLE Contact final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.Contact) */ {
 public:
  inline Contact() : Contact(nullptr) {}
  ~Contact() override;
  explicit constexpr Contact(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  Contact(const Contact& from);
  Contact(Contact&& from) noexcept
    : Contact() {
    *this = ::std::move(from);
  }

  inline Contact& operator=(const Contact& from) {
    CopyFrom(from);
    return *this;
  }
  inline Contact& operator=(Contact&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Contact& default_instance() {
    return *internal_default_instance();
  }
  static inline const Contact* internal_default_instance() {
    return reinterpret_cast<const Contact*>(
               &_Contact_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(Contact& a, Contact& b) {
    a.Swap(&b);
  }
  inline void Swap(Contact* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Contact* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline Contact* New() const final {
    return new Contact();
  }

  Contact* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<Contact>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const Contact& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const Contact& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Contact* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.Contact";
  }
  protected:
  explicit Contact(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kPositionFieldNumber = 4,
    kNormalFieldNumber = 5,
    kDepthFieldNumber = 6,
    kWrenchFieldNumber = 7,
    kHeaderFieldNumber = 1,
    kCollision1FieldNumber = 2,
    kCollision2FieldNumber = 3,
    kWorldFieldNumber = 8,
  };
  // repeated .ignition.msgs.Vector3d position = 4;
  int position_size() const;
  private:
  int _internal_position_size() const;
  public:
  void clear_position();
  ::ignition::msgs::Vector3d* mutable_position(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Vector3d >*
      mutable_position();
  private:
  const ::ignition::msgs::Vector3d& _internal_position(int index) const;
  ::ignition::msgs::Vector3d* _internal_add_position();
  public:
  const ::ignition::msgs::Vector3d& position(int index) const;
  ::ignition::msgs::Vector3d* add_position();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Vector3d >&
      position() const;

  // repeated .ignition.msgs.Vector3d normal = 5;
  int normal_size() const;
  private:
  int _internal_normal_size() const;
  public:
  void clear_normal();
  ::ignition::msgs::Vector3d* mutable_normal(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Vector3d >*
      mutable_normal();
  private:
  const ::ignition::msgs::Vector3d& _internal_normal(int index) const;
  ::ignition::msgs::Vector3d* _internal_add_normal();
  public:
  const ::ignition::msgs::Vector3d& normal(int index) const;
  ::ignition::msgs::Vector3d* add_normal();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Vector3d >&
      normal() const;

  // repeated double depth = 6;
  int depth_size() const;
  private:
  int _internal_depth_size() const;
  public:
  void clear_depth();
  private:
  double _internal_depth(int index) const;
  const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
      _internal_depth() const;
  void _internal_add_depth(double value);
  ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
      _internal_mutable_depth();
  public:
  double depth(int index) const;
  void set_depth(int index, double value);
  void add_depth(double value);
  const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
      depth() const;
  ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
      mutable_depth();

  // repeated .ignition.msgs.JointWrench wrench = 7;
  int wrench_size() const;
  private:
  int _internal_wrench_size() const;
  public:
  void clear_wrench();
  ::ignition::msgs::JointWrench* mutable_wrench(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::JointWrench >*
      mutable_wrench();
  private:
  const ::ignition::msgs::JointWrench& _internal_wrench(int index) const;
  ::ignition::msgs::JointWrench* _internal_add_wrench();
  public:
  const ::ignition::msgs::JointWrench& wrench(int index) const;
  ::ignition::msgs::JointWrench* add_wrench();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::JointWrench >&
      wrench() const;

  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // .ignition.msgs.Entity collision1 = 2;
  bool has_collision1() const;
  private:
  bool _internal_has_collision1() const;
  public:
  void clear_collision1();
  const ::ignition::msgs::Entity& collision1() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Entity* release_collision1();
  ::ignition::msgs::Entity* mutable_collision1();
  void set_allocated_collision1(::ignition::msgs::Entity* collision1);
  private:
  const ::ignition::msgs::Entity& _internal_collision1() const;
  ::ignition::msgs::Entity* _internal_mutable_collision1();
  public:
  void unsafe_arena_set_allocated_collision1(
      ::ignition::msgs::Entity* collision1);
  ::ignition::msgs::Entity* unsafe_arena_release_collision1();

  // .ignition.msgs.Entity collision2 = 3;
  bool has_collision2() const;
  private:
  bool _internal_has_collision2() const;
  public:
  void clear_collision2();
  const ::ignition::msgs::Entity& collision2() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Entity* release_collision2();
  ::ignition::msgs::Entity* mutable_collision2();
  void set_allocated_collision2(::ignition::msgs::Entity* collision2);
  private:
  const ::ignition::msgs::Entity& _internal_collision2() const;
  ::ignition::msgs::Entity* _internal_mutable_collision2();
  public:
  void unsafe_arena_set_allocated_collision2(
      ::ignition::msgs::Entity* collision2);
  ::ignition::msgs::Entity* unsafe_arena_release_collision2();

  // .ignition.msgs.Entity world = 8;
  bool has_world() const;
  private:
  bool _internal_has_world() const;
  public:
  void clear_world();
  const ::ignition::msgs::Entity& world() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Entity* release_world();
  ::ignition::msgs::Entity* mutable_world();
  void set_allocated_world(::ignition::msgs::Entity* world);
  private:
  const ::ignition::msgs::Entity& _internal_world() const;
  ::ignition::msgs::Entity* _internal_mutable_world();
  public:
  void unsafe_arena_set_allocated_world(
      ::ignition::msgs::Entity* world);
  ::ignition::msgs::Entity* unsafe_arena_release_world();

  // @@protoc_insertion_point(class_scope:ignition.msgs.Contact)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Vector3d > position_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Vector3d > normal_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedField< double > depth_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::JointWrench > wrench_;
  ::ignition::msgs::Header* header_;
  ::ignition::msgs::Entity* collision1_;
  ::ignition::msgs::Entity* collision2_;
  ::ignition::msgs::Entity* world_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fcontact_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// Contact

// .ignition.msgs.Header header = 1;
inline bool Contact::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool Contact::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& Contact::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& Contact::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Contact.header)
  return _internal_header();
}
inline void Contact::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Contact.header)
}
inline ::ignition::msgs::Header* Contact::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* Contact::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Contact.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* Contact::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* Contact::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Contact.header)
  return _msg;
}
inline void Contact::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Contact.header)
}

// .ignition.msgs.Entity collision1 = 2;
inline bool Contact::_internal_has_collision1() const {
  return this != internal_default_instance() && collision1_ != nullptr;
}
inline bool Contact::has_collision1() const {
  return _internal_has_collision1();
}
inline const ::ignition::msgs::Entity& Contact::_internal_collision1() const {
  const ::ignition::msgs::Entity* p = collision1_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Entity&>(
      ::ignition::msgs::_Entity_default_instance_);
}
inline const ::ignition::msgs::Entity& Contact::collision1() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Contact.collision1)
  return _internal_collision1();
}
inline void Contact::unsafe_arena_set_allocated_collision1(
    ::ignition::msgs::Entity* collision1) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(collision1_);
  }
  collision1_ = collision1;
  if (collision1) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Contact.collision1)
}
inline ::ignition::msgs::Entity* Contact::release_collision1() {
  
  ::ignition::msgs::Entity* temp = collision1_;
  collision1_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Entity* Contact::unsafe_arena_release_collision1() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Contact.collision1)
  
  ::ignition::msgs::Entity* temp = collision1_;
  collision1_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Entity* Contact::_internal_mutable_collision1() {
  
  if (collision1_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Entity>(GetArenaForAllocation());
    collision1_ = p;
  }
  return collision1_;
}
inline ::ignition::msgs::Entity* Contact::mutable_collision1() {
  ::ignition::msgs::Entity* _msg = _internal_mutable_collision1();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Contact.collision1)
  return _msg;
}
inline void Contact::set_allocated_collision1(::ignition::msgs::Entity* collision1) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(collision1_);
  }
  if (collision1) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(collision1));
    if (message_arena != submessage_arena) {
      collision1 = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, collision1, submessage_arena);
    }
    
  } else {
    
  }
  collision1_ = collision1;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Contact.collision1)
}

// .ignition.msgs.Entity collision2 = 3;
inline bool Contact::_internal_has_collision2() const {
  return this != internal_default_instance() && collision2_ != nullptr;
}
inline bool Contact::has_collision2() const {
  return _internal_has_collision2();
}
inline const ::ignition::msgs::Entity& Contact::_internal_collision2() const {
  const ::ignition::msgs::Entity* p = collision2_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Entity&>(
      ::ignition::msgs::_Entity_default_instance_);
}
inline const ::ignition::msgs::Entity& Contact::collision2() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Contact.collision2)
  return _internal_collision2();
}
inline void Contact::unsafe_arena_set_allocated_collision2(
    ::ignition::msgs::Entity* collision2) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(collision2_);
  }
  collision2_ = collision2;
  if (collision2) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Contact.collision2)
}
inline ::ignition::msgs::Entity* Contact::release_collision2() {
  
  ::ignition::msgs::Entity* temp = collision2_;
  collision2_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Entity* Contact::unsafe_arena_release_collision2() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Contact.collision2)
  
  ::ignition::msgs::Entity* temp = collision2_;
  collision2_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Entity* Contact::_internal_mutable_collision2() {
  
  if (collision2_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Entity>(GetArenaForAllocation());
    collision2_ = p;
  }
  return collision2_;
}
inline ::ignition::msgs::Entity* Contact::mutable_collision2() {
  ::ignition::msgs::Entity* _msg = _internal_mutable_collision2();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Contact.collision2)
  return _msg;
}
inline void Contact::set_allocated_collision2(::ignition::msgs::Entity* collision2) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(collision2_);
  }
  if (collision2) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(collision2));
    if (message_arena != submessage_arena) {
      collision2 = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, collision2, submessage_arena);
    }
    
  } else {
    
  }
  collision2_ = collision2;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Contact.collision2)
}

// repeated .ignition.msgs.Vector3d position = 4;
inline int Contact::_internal_position_size() const {
  return position_.size();
}
inline int Contact::position_size() const {
  return _internal_position_size();
}
inline ::ignition::msgs::Vector3d* Contact::mutable_position(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Contact.position)
  return position_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Vector3d >*
Contact::mutable_position() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Contact.position)
  return &position_;
}
inline const ::ignition::msgs::Vector3d& Contact::_internal_position(int index) const {
  return position_.Get(index);
}
inline const ::ignition::msgs::Vector3d& Contact::position(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Contact.position)
  return _internal_position(index);
}
inline ::ignition::msgs::Vector3d* Contact::_internal_add_position() {
  return position_.Add();
}
inline ::ignition::msgs::Vector3d* Contact::add_position() {
  ::ignition::msgs::Vector3d* _add = _internal_add_position();
  // @@protoc_insertion_point(field_add:ignition.msgs.Contact.position)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Vector3d >&
Contact::position() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Contact.position)
  return position_;
}

// repeated .ignition.msgs.Vector3d normal = 5;
inline int Contact::_internal_normal_size() const {
  return normal_.size();
}
inline int Contact::normal_size() const {
  return _internal_normal_size();
}
inline ::ignition::msgs::Vector3d* Contact::mutable_normal(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Contact.normal)
  return normal_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Vector3d >*
Contact::mutable_normal() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Contact.normal)
  return &normal_;
}
inline const ::ignition::msgs::Vector3d& Contact::_internal_normal(int index) const {
  return normal_.Get(index);
}
inline const ::ignition::msgs::Vector3d& Contact::normal(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Contact.normal)
  return _internal_normal(index);
}
inline ::ignition::msgs::Vector3d* Contact::_internal_add_normal() {
  return normal_.Add();
}
inline ::ignition::msgs::Vector3d* Contact::add_normal() {
  ::ignition::msgs::Vector3d* _add = _internal_add_normal();
  // @@protoc_insertion_point(field_add:ignition.msgs.Contact.normal)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Vector3d >&
Contact::normal() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Contact.normal)
  return normal_;
}

// repeated double depth = 6;
inline int Contact::_internal_depth_size() const {
  return depth_.size();
}
inline int Contact::depth_size() const {
  return _internal_depth_size();
}
inline void Contact::clear_depth() {
  depth_.Clear();
}
inline double Contact::_internal_depth(int index) const {
  return depth_.Get(index);
}
inline double Contact::depth(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Contact.depth)
  return _internal_depth(index);
}
inline void Contact::set_depth(int index, double value) {
  depth_.Set(index, value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Contact.depth)
}
inline void Contact::_internal_add_depth(double value) {
  depth_.Add(value);
}
inline void Contact::add_depth(double value) {
  _internal_add_depth(value);
  // @@protoc_insertion_point(field_add:ignition.msgs.Contact.depth)
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
Contact::_internal_depth() const {
  return depth_;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
Contact::depth() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Contact.depth)
  return _internal_depth();
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
Contact::_internal_mutable_depth() {
  return &depth_;
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
Contact::mutable_depth() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Contact.depth)
  return _internal_mutable_depth();
}

// repeated .ignition.msgs.JointWrench wrench = 7;
inline int Contact::_internal_wrench_size() const {
  return wrench_.size();
}
inline int Contact::wrench_size() const {
  return _internal_wrench_size();
}
inline ::ignition::msgs::JointWrench* Contact::mutable_wrench(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Contact.wrench)
  return wrench_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::JointWrench >*
Contact::mutable_wrench() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Contact.wrench)
  return &wrench_;
}
inline const ::ignition::msgs::JointWrench& Contact::_internal_wrench(int index) const {
  return wrench_.Get(index);
}
inline const ::ignition::msgs::JointWrench& Contact::wrench(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Contact.wrench)
  return _internal_wrench(index);
}
inline ::ignition::msgs::JointWrench* Contact::_internal_add_wrench() {
  return wrench_.Add();
}
inline ::ignition::msgs::JointWrench* Contact::add_wrench() {
  ::ignition::msgs::JointWrench* _add = _internal_add_wrench();
  // @@protoc_insertion_point(field_add:ignition.msgs.Contact.wrench)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::JointWrench >&
Contact::wrench() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Contact.wrench)
  return wrench_;
}

// .ignition.msgs.Entity world = 8;
inline bool Contact::_internal_has_world() const {
  return this != internal_default_instance() && world_ != nullptr;
}
inline bool Contact::has_world() const {
  return _internal_has_world();
}
inline const ::ignition::msgs::Entity& Contact::_internal_world() const {
  const ::ignition::msgs::Entity* p = world_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Entity&>(
      ::ignition::msgs::_Entity_default_instance_);
}
inline const ::ignition::msgs::Entity& Contact::world() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Contact.world)
  return _internal_world();
}
inline void Contact::unsafe_arena_set_allocated_world(
    ::ignition::msgs::Entity* world) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(world_);
  }
  world_ = world;
  if (world) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Contact.world)
}
inline ::ignition::msgs::Entity* Contact::release_world() {
  
  ::ignition::msgs::Entity* temp = world_;
  world_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Entity* Contact::unsafe_arena_release_world() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Contact.world)
  
  ::ignition::msgs::Entity* temp = world_;
  world_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Entity* Contact::_internal_mutable_world() {
  
  if (world_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Entity>(GetArenaForAllocation());
    world_ = p;
  }
  return world_;
}
inline ::ignition::msgs::Entity* Contact::mutable_world() {
  ::ignition::msgs::Entity* _msg = _internal_mutable_world();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Contact.world)
  return _msg;
}
inline void Contact::set_allocated_world(::ignition::msgs::Entity* world) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(world_);
  }
  if (world) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(world));
    if (message_arena != submessage_arena) {
      world = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, world, submessage_arena);
    }
    
  } else {
    
  }
  world_ = world;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Contact.world)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef std::unique_ptr<Contact> ContactUniquePtr;
typedef std::unique_ptr<const Contact> ConstContactUniquePtr;
typedef std::shared_ptr<Contact> ContactSharedPtr;
typedef std::shared_ptr<const Contact> ConstContactSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fcontact_2eproto
