// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/axis.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2faxis_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2faxis_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018001 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/vector3d.pb.h"
#include "ignition/msgs/header.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2faxis_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2faxis_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2faxis_2eproto;
namespace ignition {
namespace msgs {
class Axis;
struct AxisDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern AxisDefaultTypeInternal _Axis_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::Axis* Arena::CreateMaybeMessage<::ignition::msgs::Axis>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

// ===================================================================

class IGNITION_MSGS_VISIBLE Axis final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.Axis) */ {
 public:
  inline Axis() : Axis(nullptr) {}
  ~Axis() override;
  explicit constexpr Axis(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  Axis(const Axis& from);
  Axis(Axis&& from) noexcept
    : Axis() {
    *this = ::std::move(from);
  }

  inline Axis& operator=(const Axis& from) {
    CopyFrom(from);
    return *this;
  }
  inline Axis& operator=(Axis&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Axis& default_instance() {
    return *internal_default_instance();
  }
  static inline const Axis* internal_default_instance() {
    return reinterpret_cast<const Axis*>(
               &_Axis_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(Axis& a, Axis& b) {
    a.Swap(&b);
  }
  inline void Swap(Axis* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Axis* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline Axis* New() const final {
    return new Axis();
  }

  Axis* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<Axis>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const Axis& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const Axis& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Axis* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.Axis";
  }
  protected:
  explicit Axis(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kXyzExpressedInFieldNumber = 14,
    kHeaderFieldNumber = 1,
    kXyzFieldNumber = 2,
    kLimitLowerFieldNumber = 3,
    kLimitUpperFieldNumber = 4,
    kLimitEffortFieldNumber = 5,
    kLimitVelocityFieldNumber = 6,
    kDampingFieldNumber = 7,
    kFrictionFieldNumber = 8,
    kPositionFieldNumber = 10,
    kVelocityFieldNumber = 11,
    kForceFieldNumber = 12,
    kAccelerationFieldNumber = 13,
  };
  // string xyz_expressed_in = 14;
  void clear_xyz_expressed_in();
  const std::string& xyz_expressed_in() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_xyz_expressed_in(ArgT0&& arg0, ArgT... args);
  std::string* mutable_xyz_expressed_in();
  PROTOBUF_MUST_USE_RESULT std::string* release_xyz_expressed_in();
  void set_allocated_xyz_expressed_in(std::string* xyz_expressed_in);
  private:
  const std::string& _internal_xyz_expressed_in() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_xyz_expressed_in(const std::string& value);
  std::string* _internal_mutable_xyz_expressed_in();
  public:

  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // .ignition.msgs.Vector3d xyz = 2;
  bool has_xyz() const;
  private:
  bool _internal_has_xyz() const;
  public:
  void clear_xyz();
  const ::ignition::msgs::Vector3d& xyz() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Vector3d* release_xyz();
  ::ignition::msgs::Vector3d* mutable_xyz();
  void set_allocated_xyz(::ignition::msgs::Vector3d* xyz);
  private:
  const ::ignition::msgs::Vector3d& _internal_xyz() const;
  ::ignition::msgs::Vector3d* _internal_mutable_xyz();
  public:
  void unsafe_arena_set_allocated_xyz(
      ::ignition::msgs::Vector3d* xyz);
  ::ignition::msgs::Vector3d* unsafe_arena_release_xyz();

  // double limit_lower = 3;
  void clear_limit_lower();
  double limit_lower() const;
  void set_limit_lower(double value);
  private:
  double _internal_limit_lower() const;
  void _internal_set_limit_lower(double value);
  public:

  // double limit_upper = 4;
  void clear_limit_upper();
  double limit_upper() const;
  void set_limit_upper(double value);
  private:
  double _internal_limit_upper() const;
  void _internal_set_limit_upper(double value);
  public:

  // double limit_effort = 5;
  void clear_limit_effort();
  double limit_effort() const;
  void set_limit_effort(double value);
  private:
  double _internal_limit_effort() const;
  void _internal_set_limit_effort(double value);
  public:

  // double limit_velocity = 6;
  void clear_limit_velocity();
  double limit_velocity() const;
  void set_limit_velocity(double value);
  private:
  double _internal_limit_velocity() const;
  void _internal_set_limit_velocity(double value);
  public:

  // double damping = 7;
  void clear_damping();
  double damping() const;
  void set_damping(double value);
  private:
  double _internal_damping() const;
  void _internal_set_damping(double value);
  public:

  // double friction = 8;
  void clear_friction();
  double friction() const;
  void set_friction(double value);
  private:
  double _internal_friction() const;
  void _internal_set_friction(double value);
  public:

  // double position = 10;
  void clear_position();
  double position() const;
  void set_position(double value);
  private:
  double _internal_position() const;
  void _internal_set_position(double value);
  public:

  // double velocity = 11;
  void clear_velocity();
  double velocity() const;
  void set_velocity(double value);
  private:
  double _internal_velocity() const;
  void _internal_set_velocity(double value);
  public:

  // double force = 12;
  void clear_force();
  double force() const;
  void set_force(double value);
  private:
  double _internal_force() const;
  void _internal_set_force(double value);
  public:

  // double acceleration = 13;
  void clear_acceleration();
  double acceleration() const;
  void set_acceleration(double value);
  private:
  double _internal_acceleration() const;
  void _internal_set_acceleration(double value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.Axis)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr xyz_expressed_in_;
  ::ignition::msgs::Header* header_;
  ::ignition::msgs::Vector3d* xyz_;
  double limit_lower_;
  double limit_upper_;
  double limit_effort_;
  double limit_velocity_;
  double damping_;
  double friction_;
  double position_;
  double velocity_;
  double force_;
  double acceleration_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2faxis_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// Axis

// .ignition.msgs.Header header = 1;
inline bool Axis::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool Axis::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& Axis::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& Axis::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Axis.header)
  return _internal_header();
}
inline void Axis::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Axis.header)
}
inline ::ignition::msgs::Header* Axis::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* Axis::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Axis.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* Axis::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* Axis::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Axis.header)
  return _msg;
}
inline void Axis::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Axis.header)
}

// .ignition.msgs.Vector3d xyz = 2;
inline bool Axis::_internal_has_xyz() const {
  return this != internal_default_instance() && xyz_ != nullptr;
}
inline bool Axis::has_xyz() const {
  return _internal_has_xyz();
}
inline const ::ignition::msgs::Vector3d& Axis::_internal_xyz() const {
  const ::ignition::msgs::Vector3d* p = xyz_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Vector3d&>(
      ::ignition::msgs::_Vector3d_default_instance_);
}
inline const ::ignition::msgs::Vector3d& Axis::xyz() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Axis.xyz)
  return _internal_xyz();
}
inline void Axis::unsafe_arena_set_allocated_xyz(
    ::ignition::msgs::Vector3d* xyz) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(xyz_);
  }
  xyz_ = xyz;
  if (xyz) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Axis.xyz)
}
inline ::ignition::msgs::Vector3d* Axis::release_xyz() {
  
  ::ignition::msgs::Vector3d* temp = xyz_;
  xyz_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Vector3d* Axis::unsafe_arena_release_xyz() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Axis.xyz)
  
  ::ignition::msgs::Vector3d* temp = xyz_;
  xyz_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Vector3d* Axis::_internal_mutable_xyz() {
  
  if (xyz_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Vector3d>(GetArenaForAllocation());
    xyz_ = p;
  }
  return xyz_;
}
inline ::ignition::msgs::Vector3d* Axis::mutable_xyz() {
  ::ignition::msgs::Vector3d* _msg = _internal_mutable_xyz();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Axis.xyz)
  return _msg;
}
inline void Axis::set_allocated_xyz(::ignition::msgs::Vector3d* xyz) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(xyz_);
  }
  if (xyz) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(xyz));
    if (message_arena != submessage_arena) {
      xyz = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, xyz, submessage_arena);
    }
    
  } else {
    
  }
  xyz_ = xyz;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Axis.xyz)
}

// double limit_lower = 3;
inline void Axis::clear_limit_lower() {
  limit_lower_ = 0;
}
inline double Axis::_internal_limit_lower() const {
  return limit_lower_;
}
inline double Axis::limit_lower() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Axis.limit_lower)
  return _internal_limit_lower();
}
inline void Axis::_internal_set_limit_lower(double value) {
  
  limit_lower_ = value;
}
inline void Axis::set_limit_lower(double value) {
  _internal_set_limit_lower(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Axis.limit_lower)
}

// double limit_upper = 4;
inline void Axis::clear_limit_upper() {
  limit_upper_ = 0;
}
inline double Axis::_internal_limit_upper() const {
  return limit_upper_;
}
inline double Axis::limit_upper() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Axis.limit_upper)
  return _internal_limit_upper();
}
inline void Axis::_internal_set_limit_upper(double value) {
  
  limit_upper_ = value;
}
inline void Axis::set_limit_upper(double value) {
  _internal_set_limit_upper(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Axis.limit_upper)
}

// double limit_effort = 5;
inline void Axis::clear_limit_effort() {
  limit_effort_ = 0;
}
inline double Axis::_internal_limit_effort() const {
  return limit_effort_;
}
inline double Axis::limit_effort() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Axis.limit_effort)
  return _internal_limit_effort();
}
inline void Axis::_internal_set_limit_effort(double value) {
  
  limit_effort_ = value;
}
inline void Axis::set_limit_effort(double value) {
  _internal_set_limit_effort(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Axis.limit_effort)
}

// double limit_velocity = 6;
inline void Axis::clear_limit_velocity() {
  limit_velocity_ = 0;
}
inline double Axis::_internal_limit_velocity() const {
  return limit_velocity_;
}
inline double Axis::limit_velocity() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Axis.limit_velocity)
  return _internal_limit_velocity();
}
inline void Axis::_internal_set_limit_velocity(double value) {
  
  limit_velocity_ = value;
}
inline void Axis::set_limit_velocity(double value) {
  _internal_set_limit_velocity(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Axis.limit_velocity)
}

// double damping = 7;
inline void Axis::clear_damping() {
  damping_ = 0;
}
inline double Axis::_internal_damping() const {
  return damping_;
}
inline double Axis::damping() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Axis.damping)
  return _internal_damping();
}
inline void Axis::_internal_set_damping(double value) {
  
  damping_ = value;
}
inline void Axis::set_damping(double value) {
  _internal_set_damping(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Axis.damping)
}

// double friction = 8;
inline void Axis::clear_friction() {
  friction_ = 0;
}
inline double Axis::_internal_friction() const {
  return friction_;
}
inline double Axis::friction() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Axis.friction)
  return _internal_friction();
}
inline void Axis::_internal_set_friction(double value) {
  
  friction_ = value;
}
inline void Axis::set_friction(double value) {
  _internal_set_friction(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Axis.friction)
}

// double position = 10;
inline void Axis::clear_position() {
  position_ = 0;
}
inline double Axis::_internal_position() const {
  return position_;
}
inline double Axis::position() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Axis.position)
  return _internal_position();
}
inline void Axis::_internal_set_position(double value) {
  
  position_ = value;
}
inline void Axis::set_position(double value) {
  _internal_set_position(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Axis.position)
}

// double velocity = 11;
inline void Axis::clear_velocity() {
  velocity_ = 0;
}
inline double Axis::_internal_velocity() const {
  return velocity_;
}
inline double Axis::velocity() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Axis.velocity)
  return _internal_velocity();
}
inline void Axis::_internal_set_velocity(double value) {
  
  velocity_ = value;
}
inline void Axis::set_velocity(double value) {
  _internal_set_velocity(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Axis.velocity)
}

// double force = 12;
inline void Axis::clear_force() {
  force_ = 0;
}
inline double Axis::_internal_force() const {
  return force_;
}
inline double Axis::force() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Axis.force)
  return _internal_force();
}
inline void Axis::_internal_set_force(double value) {
  
  force_ = value;
}
inline void Axis::set_force(double value) {
  _internal_set_force(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Axis.force)
}

// double acceleration = 13;
inline void Axis::clear_acceleration() {
  acceleration_ = 0;
}
inline double Axis::_internal_acceleration() const {
  return acceleration_;
}
inline double Axis::acceleration() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Axis.acceleration)
  return _internal_acceleration();
}
inline void Axis::_internal_set_acceleration(double value) {
  
  acceleration_ = value;
}
inline void Axis::set_acceleration(double value) {
  _internal_set_acceleration(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Axis.acceleration)
}

// string xyz_expressed_in = 14;
inline void Axis::clear_xyz_expressed_in() {
  xyz_expressed_in_.ClearToEmpty();
}
inline const std::string& Axis::xyz_expressed_in() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Axis.xyz_expressed_in)
  return _internal_xyz_expressed_in();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Axis::set_xyz_expressed_in(ArgT0&& arg0, ArgT... args) {
 
 xyz_expressed_in_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Axis.xyz_expressed_in)
}
inline std::string* Axis::mutable_xyz_expressed_in() {
  std::string* _s = _internal_mutable_xyz_expressed_in();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Axis.xyz_expressed_in)
  return _s;
}
inline const std::string& Axis::_internal_xyz_expressed_in() const {
  return xyz_expressed_in_.Get();
}
inline void Axis::_internal_set_xyz_expressed_in(const std::string& value) {
  
  xyz_expressed_in_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Axis::_internal_mutable_xyz_expressed_in() {
  
  return xyz_expressed_in_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Axis::release_xyz_expressed_in() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Axis.xyz_expressed_in)
  return xyz_expressed_in_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Axis::set_allocated_xyz_expressed_in(std::string* xyz_expressed_in) {
  if (xyz_expressed_in != nullptr) {
    
  } else {
    
  }
  xyz_expressed_in_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), xyz_expressed_in,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Axis.xyz_expressed_in)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef std::unique_ptr<Axis> AxisUniquePtr;
typedef std::unique_ptr<const Axis> ConstAxisUniquePtr;
typedef std::shared_ptr<Axis> AxisSharedPtr;
typedef std::shared_ptr<const Axis> ConstAxisSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2faxis_2eproto
