# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/performance_sensor_metrics.proto

require 'ignition/msgs/double_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/performance_sensor_metrics.proto", :syntax => :proto3) do
    add_message "ignition.msgs.PerformanceSensorMetrics" do
      optional :name, :string, 1
      optional :real_update_rate, :double, 2
      optional :sim_update_rate, :double, 3
      optional :nominal_update_rate, :double, 4
      optional :fps_optional, :message, 5, "ignition.msgs.Double"
    end
  end
end

module Ignition
  module Msgs
    PerformanceSensorMetrics = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.PerformanceSensorMetrics").msgclass
  end
end
