# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/world_control.proto

require 'ignition/msgs/world_reset_pb'
require 'ignition/msgs/header_pb'
require 'ignition/msgs/time_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/world_control.proto", :syntax => :proto3) do
    add_message "ignition.msgs.WorldControl" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :pause, :bool, 2
      optional :step, :bool, 3
      optional :multi_step, :uint32, 4
      optional :reset, :message, 5, "ignition.msgs.WorldReset"
      optional :seed, :uint32, 6
      optional :run_to_sim_time, :message, 7, "ignition.msgs.Time"
    end
  end
end

module Ignition
  module Msgs
    WorldControl = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.WorldControl").msgclass
  end
end
